#!/bin/sh
#SBATCH -J fluent
#SBATCH -N 1
#SBATCH -o job.%j.out
#SBATCH --partition=mem_0384
#SBATCH --qos=mem_0384
#SBATCH --ntasks-per-node=24
#SBATCH --threads-per-core=1
#SBATCH --time=04:00:00

module purge
module load ANSYS-Fluent/2019R3

JOURNALFILE=fluent.jou

if [ $SLURM_NNODES -eq 1 ]; then
    # Single node with shared memory
    fluent 3ddp -g -t $SLURM_NTASKS -i $JOURNALFILE > fluent.log 
else
    # Multi-node
    fluent 3ddp  \                # call fluent with 3D double precision solver
    -g \                          # run without GUI
    -slurm -t $SLURM_NTASKS \     # run via SLURM with NTASKS
    -pinfiniband \                # use Infiniband interconnect
    -mpi=openmpi \                # use IntelMPI
    -i $JOURNALFILE > fluent.log  # input file
fi
